@@ -17,4 +17,8 @@ class GenerativeModelBase(ABC):
 
     @abstractmethod
     def sample(self, *args, **kwargs):
-        raise NotImplemented("sample method is not implemented")
\ No newline at end of file
+        raise NotImplemented("sample method is not implemented")
+
+    @abstractmethod
+    def set_mode(self, mode: str):
+        raise NotImplemented("set_mode method is not implemented")
\ No newline at end of file
